@@ -1,19 +1,26 @@
-# This file is Copyright (c) 2019 Antony Pavlov <antonynpavlov@gmail.com>
-# License: BSD
+#
+# This file is part of LiteX-Boards.
+#
+# Copyright (c) 2019 Antony Pavlov <antonynpavlov@gmail.com>
+# SPDX-License-Identifier: BSD-2-Clause
 
 from litex.build.generic_platform import *
 from litex.build.altera import AlteraPlatform
+from litex.build.altera.programmer import USBBlaster
 
-# IOs ------------------------------------------------------------------
+# IOs ----------------------------------------------------------------------------------------------
 
 _io = [
+    # Clk
     ("clk50", 0, Pins("AF14"), IOStandard("3.3-V LVTTL")),
 
+    # Serial
     ("serial", 0,
         Subsignal("tx", Pins("AC18"), IOStandard("3.3-V LVTTL")), # JP1 GPIO[0]
         Subsignal("rx", Pins("Y17"),  IOStandard("3.3-V LVTTL"))  # JP1 GPIO[1]
     ),
 
+    # SDR SDRAM
     ("sdram_clock", 0, Pins("AH12"), IOStandard("3.3-V LVTTL")),
     ("sdram", 0,
         Subsignal("a",     Pins(
@@ -33,7 +40,7 @@ _io = [
     ),
 ]
 
-# Platform -------------------------------------------------------------
+# Platform -----------------------------------------------------------------------------------------
 
 class Platform(AlteraPlatform):
     default_clk_name   = "clk50"
@@ -41,3 +48,10 @@ class Platform(AlteraPlatform):
 
     def __init__(self):
         AlteraPlatform.__init__(self, "5CSEMA5F31C6", _io)
+
+    def create_programmer(self):
+        return USBBlaster()
+
+    def do_finalize(self, fragment):
+        AlteraPlatform.do_finalize(self, fragment)
+        self.add_period_constraint(self.lookup_request("clk50", loose=True), 1e9/50e6)
